pub struct SegmentLayout { /* private fields */ }Expand description
Offsets and lengths for one segment in a MessageLayout.
Implementations
Sourceimpl SegmentLayout
impl SegmentLayout
Sourcepub const fn plaintext_offset(self) -> u64
pub const fn plaintext_offset(self) -> u64
Returns this segment’s byte offset in the complete plaintext.
Sourcepub const fn plaintext_length(self) -> usize
pub const fn plaintext_length(self) -> usize
Returns this segment’s plaintext length.
Sourcepub const fn ciphertext_offset(self) -> u64
pub const fn ciphertext_offset(self) -> u64
Returns this segment’s byte offset in the complete ciphertext, including the FLOE header.
Sourcepub const fn ciphertext_length(self) -> usize
pub const fn ciphertext_length(self) -> usize
Returns this segment’s ciphertext length.
Sourcepub const fn kind(self) -> SegmentKind
pub const fn kind(self) -> SegmentKind
Returns whether this is an internal or final segment.